@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "circe" "2.14"
+(define-package "circe" "20251013.1911"
   "Client for IRC in Emacs."
   '((emacs  "25.1")
     (cl-lib "0.5"))
   :url "https://github.com/emacs-circe/circe"
-  :commit "9d9f63fd7cf8812797eb0ef77d7969e7387a9eb9"
-  :revdesc "v2.14-0-g9d9f63fd7cf8"
+  :commit "e909ff49e59c396b19564855a3f282684a4e716e"
+  :revdesc "e909ff49e59c"
   :keywords '("irc" "chat" "comm")
   :authors '(("Jorgen Schaefer" . "forcer@forcix.cx"))
   :maintainers '(("Jorgen Schaefer" . "forcer@forcix.cx")))
